@@ -1,5 +1,5 @@
 /* GNU ddrescue - Data recovery tool
-   Copyright (C) 2004-2022 Antonio Diaz Diaz.
+   Copyright (C) 2004-2024 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -52,14 +52,6 @@ void Block::align_end( const int alignment )
   }
 
 
-void Block::crop( const Block & b )
-  {
-  const long long p = std::max( pos_, b.pos_ );
-  const long long s = std::max( 0LL, std::min( end(), b.end() ) - p );
-  pos_ = p; size_ = s;
-  }
-
-
 bool Block::join( const Block & b )		// join contiguous blocks
   {
   if( this->follows( b ) ) pos_ = b.pos_;
@@ -71,11 +63,11 @@ bool Block::join( const Block & b )		// join contiguous blocks
   }
 
 
-// shift the boundary of two consecutive Blocks
-void Block::shift_boundary( Block & b, const long long pos )
+// move the boundary of two consecutive Blocks to pos
+void Block::move_boundary( Block & b, const long long pos )
   {
   if( end() != b.pos_ || pos <= pos_ || pos >= b.end() )
-    internal_error( "bad argument shifting the border of two Blocks." );
+    internal_error( "bad argument moving the boundary of two Blocks." );
   b.size_ = b.end() - pos; b.pos_ = pos; size_ = pos - pos_;
   }
 
